@@ -20,6 +20,7 @@ package e2e
 
 import (
 	"context"
+	"errors"
 	"fmt"
 	"io"
 	"math"
@@ -37,6 +38,7 @@ import (
 
 	pkgTest "knative.dev/pkg/test"
 	"knative.dev/pkg/test/ingress"
+	"knative.dev/pkg/test/spoof"
 	"knative.dev/serving/pkg/apis/autoscaling"
 	rtesting "knative.dev/serving/pkg/testing/v1"
 	"knative.dev/serving/test"
@@ -50,7 +52,7 @@ const (
 	defaultPort              = "80"
 )
 
-type grpcTest func(*testContext, string, string)
+type grpcTest func(*TestContext, string, string)
 
 // hasPort checks if a URL contains a port number
 func hasPort(u string) bool {
@@ -90,7 +92,7 @@ func dial(host, domain string) (*grpc.ClientConn, error) {
 	)
 }
 
-func unaryTest(ctx *testContext, host, domain string) {
+func unaryTest(ctx *TestContext, host, domain string) {
 	ctx.t.Helper()
 	ctx.t.Logf("Connecting to grpc-ping using host %q and authority %q", host, domain)
 	const want = "Hello!"
@@ -103,7 +105,7 @@ func unaryTest(ctx *testContext, host, domain string) {
 	}
 }
 
-func autoscaleTest(ctx *testContext, host, domain string) {
+func autoscaleTest(ctx *TestContext, host, domain string) {
 	ctx.t.Helper()
 	ctx.t.Logf("Connecting to grpc-ping using host %q and authority %q", host, domain)
 
@@ -113,7 +115,7 @@ func autoscaleTest(ctx *testContext, host, domain string) {
 	assertGRPCAutoscaleUpToNumPods(ctx, 0, 2, 60*time.Second, host, domain)
 }
 
-func loadBalancingTest(ctx *testContext, host, domain string) {
+func loadBalancingTest(ctx *TestContext, host, domain string) {
 	ctx.t.Helper()
 	ctx.t.Logf("Connecting to grpc-ping using host %q and authority %q", host, domain)
 
@@ -150,7 +152,7 @@ func loadBalancingTest(ctx *testContext, host, domain string) {
 				default:
 					got, err := pingGRPC(host, domain, wantPrefix)
 					if err != nil {
-						return fmt.Errorf("ping gRPC error: %v", err)
+						return fmt.Errorf("ping gRPC error: %w", err)
 					}
 					if !strings.HasPrefix(got, wantPrefix) {
 						return fmt.Errorf("response = %q, wantPrefix = %q", got, wantPrefix)
@@ -203,7 +205,7 @@ func generateGRPCTraffic(concurrentRequests int, host, domain string, stopChan c
 					got, err := pingGRPC(host, domain, want)
 
 					if err != nil {
-						return fmt.Errorf("ping gRPC error: %v", err)
+						return fmt.Errorf("ping gRPC error: %w", err)
 					}
 					if got != want {
 						return fmt.Errorf("response = %q, want = %q", got, want)
@@ -213,7 +215,7 @@ func generateGRPCTraffic(concurrentRequests int, host, domain string, stopChan c
 		})
 	}
 	if err := grp.Wait(); err != nil {
-		return fmt.Errorf("error processing requests %v", err)
+		return fmt.Errorf("error processing requests %w", err)
 	}
 	return nil
 }
@@ -230,12 +232,12 @@ func pingGRPC(host, domain, message string) (string, error) {
 
 	got, err := pc.Ping(context.Background(), want)
 	if err != nil {
-		return "", fmt.Errorf("could not send request: %v", err)
+		return "", fmt.Errorf("could not send request: %w", err)
 	}
 	return got.Msg, nil
 }
 
-func assertGRPCAutoscaleUpToNumPods(ctx *testContext, curPods, targetPods float64, duration time.Duration, host, domain string) {
+func assertGRPCAutoscaleUpToNumPods(ctx *TestContext, curPods, targetPods float64, duration time.Duration, host, domain string) {
 	ctx.t.Helper()
 	// Test succeeds when the number of pods meets targetPods.
 
@@ -254,7 +256,7 @@ func assertGRPCAutoscaleUpToNumPods(ctx *testContext, curPods, targetPods float6
 
 	grp.Go(func() error {
 		defer close(stopChan)
-		return checkPodScale(ctx, targetPods, minPods, maxPods, duration, true /* quick */)
+		return checkPodScale(ctx, targetPods, minPods, maxPods, time.After(duration), true /* quick */)
 	})
 
 	if err := grp.Wait(); err != nil {
@@ -262,7 +264,7 @@ func assertGRPCAutoscaleUpToNumPods(ctx *testContext, curPods, targetPods float6
 	}
 }
 
-func streamTest(tc *testContext, host, domain string) {
+func streamTest(tc *TestContext, host, domain string) {
 	tc.t.Helper()
 	tc.t.Logf("Connecting to grpc-ping using host %q and authority %q", host, domain)
 	conn, err := dial(host, domain)
@@ -308,7 +310,7 @@ func streamTest(tc *testContext, host, domain string) {
 	stream.CloseSend()
 
 	_, err = stream.Recv()
-	if err != io.EOF {
+	if !errors.Is(err, io.EOF) {
 		tc.t.Errorf("Expected EOF, got %v", err)
 	}
 }
@@ -322,15 +324,15 @@ func testGRPC(t *testing.T, f grpcTest, fopts ...rtesting.ServiceOption) {
 
 	t.Log("Creating service for grpc-ping")
 
-	names := test.ResourceNames{
+	names := &test.ResourceNames{
 		Service: test.ObjectNameForTest(t),
 		Image:   "grpc-ping",
 	}
 
 	fopts = append(fopts, rtesting.WithNamedPort("h2c"))
 
-	test.EnsureTearDown(t, clients, &names)
-	resources, err := v1test.CreateServiceReady(t, clients, &names, fopts...)
+	test.EnsureTearDown(t, clients, names)
+	resources, err := v1test.CreateServiceReady(t, clients, names, fopts...)
 	if err != nil {
 		t.Fatalf("Failed to create initial Service: %v: %v", names.Service, err)
 	}
@@ -341,7 +343,7 @@ func testGRPC(t *testing.T, f grpcTest, fopts ...rtesting.ServiceOption) {
 		clients.KubeClient,
 		t.Logf,
 		url,
-		v1test.RetryingRouteInconsistency(pkgTest.IsStatusOK),
+		v1test.RetryingRouteInconsistency(spoof.IsStatusOK),
 		"gRPCPingReadyToServe",
 		test.ServingFlags.ResolvableDomain,
 		test.AddRootCAtoTransport(context.Background(), t.Logf, clients, test.ServingFlags.HTTPS),
@@ -351,15 +353,16 @@ func testGRPC(t *testing.T, f grpcTest, fopts ...rtesting.ServiceOption) {
 
 	host := url.Host
 	if true {
-		addr, mapper, err := ingress.GetIngressEndpoint(context.Background(), clients.KubeClient.Kube, pkgTest.Flags.IngressEndpoint)
+		addr, mapper, err := ingress.GetIngressEndpoint(context.Background(), clients.KubeClient, pkgTest.Flags.IngressEndpoint)
 		if err != nil {
 			t.Fatal("Could not get service endpoint:", err)
 		}
 		host = net.JoinHostPort(addr, mapper("80"))
 	}
 
-	f(&testContext{
+	f(&TestContext{
 		t:         t,
+		logf:      t.Logf,
 		clients:   clients,
 		names:     names,
 		resources: resources,
@@ -376,7 +379,7 @@ func TestGRPCStreamingPing(t *testing.T) {
 
 func TestGRPCUnaryPingViaActivator(t *testing.T) {
 	testGRPC(t,
-		func(ctx *testContext, host, domain string) {
+		func(ctx *TestContext, host, domain string) {
 			if err := waitForActivatorEndpoints(ctx); err != nil {
 				t.Fatal("Never got Activator endpoints in the service:", err)
 			}
@@ -390,7 +393,7 @@ func TestGRPCUnaryPingViaActivator(t *testing.T) {
 
 func TestGRPCStreamingPingViaActivator(t *testing.T) {
 	testGRPC(t,
-		func(ctx *testContext, host, domain string) {
+		func(ctx *TestContext, host, domain string) {
 			if err := waitForActivatorEndpoints(ctx); err != nil {
 				t.Fatal("Never got Activator endpoints in the service:", err)
 			}
@@ -404,7 +407,7 @@ func TestGRPCStreamingPingViaActivator(t *testing.T) {
 
 func TestGRPCAutoscaleUpDownUp(t *testing.T) {
 	testGRPC(t,
-		func(ctx *testContext, host, domain string) {
+		func(ctx *TestContext, host, domain string) {
 			autoscaleTest(ctx, host, domain)
 
 		},
@@ -423,7 +426,7 @@ func TestGRPCAutoscaleUpDownUp(t *testing.T) {
 
 func TestGRPCLoadBalancing(t *testing.T) {
 	testGRPC(t,
-		func(ctx *testContext, host, domain string) {
+		func(ctx *TestContext, host, domain string) {
 			loadBalancingTest(ctx, host, domain)
 		},
 		rtesting.WithConfigAnnotations(map[string]string{
